==> ideaIC-141.3057.6-sources.jar: com/intellij/packageDependencies/DependenciesVisitorFactory.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * User: anna
 * Date: 21-Jan-2008
 */
package com.intellij.packageDependencies;

import com.intellij.openapi.components.ServiceManager;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiElementVisitor;
import com.intellij.psi.PsiRecursiveElementVisitor;
import com.intellij.psi.PsiReference;

public class DependenciesVisitorFactory {

  public static DependenciesVisitorFactory getInstance() {
    return ServiceManager.getService(DependenciesVisitorFactory.class);
  }

  public PsiElementVisitor createVisitor(final DependenciesBuilder.DependencyProcessor processor) {
    return new PsiRecursiveElementVisitor() {
      @Override
      public void visitElement(PsiElement element) {
        super.visitElement(element);
        PsiReference[] refs = element.getReferences();
        for (PsiReference ref : refs) {
          PsiElement resolved = ref.resolve();
          if (resolved != null) {
            processor.process(ref.getElement(), resolved);
          }
        }
      }
    };
  }
}

==> ideaIC-173.3531.6-sources.jar: com/intellij/packageDependencies/DependenciesVisitorFactory.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.packageDependencies;

import com.intellij.openapi.components.ServiceManager;
import com.intellij.psi.*;

/** @deprecated use {@link DependencyVisitorFactory} (to be removed in IDEA 17) */
public class DependenciesVisitorFactory {
  @SuppressWarnings("deprecation")
  public static DependenciesVisitorFactory getInstance() {
    return ServiceManager.getService(DependenciesVisitorFactory.class);
  }

  public PsiElementVisitor createVisitor(final DependenciesBuilder.DependencyProcessor processor) {
    return new PsiRecursiveElementVisitor() {
      @Override
      public void visitElement(PsiElement element) {
        super.visitElement(element);
        PsiReference[] refs = element.getReferences();
        for (PsiReference ref : refs) {
          PsiElement resolved = ref.resolve();
          if (resolved != null) {
            processor.process(ref.getElement(), resolved);
          }
        }
      }
    };
  }
}
